@@ -1,10 +1,17 @@
 package Vimana::Command;
 use warnings;
 use strict;
-
 use base qw(App::CLI App::CLI::Command);
 use Getopt::Long qw(:config no_ignore_case bundling);
 
+use constant alias => qw(
+    i       install
+    ins     install
+    s       search
+    d       download
+);
+
+
 sub invoke {
     my ($pkg , $cmd,  @args) = @_;
     my ($ret);
