@@ -4,6 +4,7 @@ use strict;
 
 use URI;
 use base qw(App::CLI::Command);
+use Vimana::Logger;
 
 sub options {
     (
@@ -13,28 +14,26 @@ sub options {
 
 
 require Vimana::VimOnline;
-require Vimana::VimOnline::Search;
-require Vimana::VimOnline::ScriptPage;
 
 sub fetch_index {
     return Vimana::VimOnline::Search->fetch(
         keyword => '',
-        show_me => 3000,
+        show_me => Vimana::VimOnline::Search->all_vim_plugins,
         order_by => 'creation_date',
         direction => 'ascending'
     );
 }
 
+
 sub run {
     my ($self, @args ) = @_;
-
-    print "Updating....\n";
+    $logger->info("Fetching...");
     my $results = fetch_index();
-    my $cnt = scalar keys %$results;
-    print "Index updated: $cnt items.\n";
 
     my $index = Vimana->index();
     $index->update( $results );
+
+    # XXX: check installed packages , calcuate outdated items
 }
 
 
